==> haskell-doctest-0.15.0-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctest
version: 0.15.0
id: doctest-0.15.0-7ZT6RjnuvG3JyHjoEtRYhS
key: doctest-0.15.0-7ZT6RjnuvG3JyHjoEtRYhS
license: MIT
copyright: (c) 2009-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/doctest#readme
synopsis: Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<http://docs.python.org/library/doctest.html>).
    .
    Documentation is at <https://github.com/sol/doctest#readme>.
category: Testing
abi: bfdcbf46a0530746a272831e5fa15233
exposed: True
exposed-modules:
    Test.DocTest
hidden-modules: Extract GhcUtil Interpreter Location Options
                PackageDBs Parse Property Run Runner Runner.Example Sandbox Util
                Language.Haskell.GhciWrapper Paths_doctest
import-dirs: /usr/lib/ghc-8.4.3/site-local/doctest-0.15.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/doctest-0.15.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/doctest-0.15.0
hs-libraries: HSdoctest-0.15.0-7ZT6RjnuvG3JyHjoEtRYhS
depends:
    base-4.11.1.0 base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
    code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2 ghc-8.4.3
    ghc-paths-0.1.0.9-BTJEJFO7ixU1hUjA8BfQ4h process-1.6.3.0
    syb-0.7-2jW43lwzJV5e7EQvU8PxV transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=1d75d8a5e04e09d5efbd2d425663f665
             code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V=79049f84d9ede2f2865e34c7a6dfc923
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             ghc-8.4.3=eef2f41901320161f5f168c67278fe14
             ghc-paths-0.1.0.9-BTJEJFO7ixU1hUjA8BfQ4h=0455818a4c9f72dd39739566b01529f1
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=5f5748e150104b1ef02b228d94777541
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html: /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-0.15.0-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctest
version: 0.15.0
id: doctest-0.15.0-ACBeKjtK7MuFTTYZK5EI6
key: doctest-0.15.0-ACBeKjtK7MuFTTYZK5EI6
license: MIT
copyright: (c) 2009-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/doctest#readme
synopsis: Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<http://docs.python.org/library/doctest.html>).
    .
    Documentation is at <https://github.com/sol/doctest#readme>.
category: Testing
abi: 8231b7053ff2c1789c826657fbac69c8
exposed: True
exposed-modules:
    Test.DocTest
hidden-modules: Extract GhcUtil Interpreter Location Options
                PackageDBs Parse Property Run Runner Runner.Example Sandbox Util
                Language.Haskell.GhciWrapper Paths_doctest
import-dirs: /usr/lib/ghc-8.4.3/site-local/doctest-0.15.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/doctest-0.15.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/doctest-0.15.0
hs-libraries: HSdoctest-0.15.0-ACBeKjtK7MuFTTYZK5EI6
depends:
    base-4.11.1.0 base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
    code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2 ghc-8.4.3
    ghc-paths-0.1.0.9-BTJEJFO7ixU1hUjA8BfQ4h process-1.6.3.0
    syb-0.7-2jW43lwzJV5e7EQvU8PxV transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=1d75d8a5e04e09d5efbd2d425663f665
             code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V=79049f84d9ede2f2865e34c7a6dfc923
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             ghc-8.4.3=eef2f41901320161f5f168c67278fe14
             ghc-paths-0.1.0.9-BTJEJFO7ixU1hUjA8BfQ4h=0455818a4c9f72dd39739566b01529f1
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=5f5748e150104b1ef02b228d94777541
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html: /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
